@@ -80,7 +80,7 @@ _DOC_ERRORS = ['enchnt','enchnt', 'fr']
 # Make version info available
 __ver_major__ = 1
 __ver_minor__ = 6
-__ver_patch__ = 3
+__ver_patch__ = 4
 __ver_sub__ = ""
 __version__ = "%d.%d.%d%s" % (__ver_major__,__ver_minor__,
                               __ver_patch__,__ver_sub__)
@@ -766,6 +766,19 @@ class DictWithPWL(Dict):
             return True
         return False
 
+    def suggest(self,word):
+        """Suggest possible spellings for a word.
+        
+        This method tries to guess the correct spelling for a given
+        word, returning the possibilities in a list.
+        """
+        suggs = Dict.suggest(self,word)
+        suggs.extend([w for w in self.pwl.suggest(word) if w not in suggs])
+        for i in xrange(len(suggs)-1,-1,-1):
+            if self.pel.check(suggs[i]):
+                del suggs[i]
+        return suggs
+
     def add(self,word):
         """Add a word to the associated personal word list.
         
